Structs
Enums
Functions
- is_
unique_ violation - Check if a sqlx error is a unique constraint violation (Postgres code 23505).
- unique_
violation_ constraint - Return the constraint name from a unique violation error, if available.
- www_
authenticate_ value - Build a
WWW-Authenticate: Bearerheader value per RFC 6750 3.1.